@@ -142,7 +142,7 @@ def getJob(userID: str, id: int):
 
 def delete(userID: str, id: str):
     url = "http://sdt-api.qcc.svc.cluster.local"
-    url_path = f"{url}/qcc/noteboo/job/{id}"
+    url_path = f"{url}/qcc/notebook/job/{id}"
 
     headers = {
         "Content-Type": "application/json",
@@ -154,5 +154,7 @@ def delete(userID: str, id: str):
 
     print(f"Deleted job : {response.text}")
 
+    if response.text == "":
+        print("Job not found.")
     return response.text
 
